跳到主要内容

Context

搜索

结构体 Context 

源代码
pub struct Context { /* 私有字段 */ }

实现

源代码

impl Context

源代码

pub fn get( src_format: Sample, src_channel_layout: ChannelLayout, src_rate: u32, dst_format: Sample, dst_channel_layout: ChannelLayout, dst_rate: u32, ) -> Result<Self, Error>

Create a resampler with the given definitions.

源代码

pub fn get_with( src_format: Sample, src_channel_layout: ChannelLayout, src_rate: u32, dst_format: Sample, dst_channel_layout: ChannelLayout, dst_rate: u32, options: Dictionary<'_>, ) -> Result<Self, Error>

Create a resampler with the given definitions and custom options dictionary.

源代码

pub fn input(&self) -> &Definition

Get the input definition.

源代码

pub fn output(&self) -> &Definition

Get the output definition.

源代码

pub fn delay(&self) -> Option<Delay>

Get the remaining delay.

源代码

pub fn run( &mut self, input: &Audio, output: &mut Audio, ) -> Result<Option<Delay>, Error>

Run the resampler from the given input to the given output.

When there are internal frames to process it will return Ok(Some(Delay { .. })).

源代码

pub fn flush(&mut self, output: &mut Audio) -> Result<Option<Delay>, Error>

Convert one of the remaining internal frames.

When there are no more internal frames Ok(None) will be returned.

trait 实现

源代码

impl Drop for Context

源代码

fn drop(&mut self)

执行该类型的析构函数。 阅读更多
源代码

impl Send for Context

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。